<?php

require_once 'Gtf.class.inc';
require_once dirname($_SERVER['SCRIPT_FILENAME']) . '/class/vitis_lib/Connection.class.inc';

/**
 * @file GtfEngine.class.inc
 * @class GtfEngine
 *
 * @author Yoann Perollet <yoann.perollet@veremes.com>.
 *
 * @brief This file contains the GtfEngine php class
 *
 * This class defines operation for one GtfEngine
 * 
 */
class GtfEngine extends GTF {

    public $oError;

    /**
     * construct
     * @param type $aPath url of the request
     * @param type $aValues parameters of the request
     * @param type $properties properties
     * @param type $bShortcut false to reinit variables
     * @param type $oConnection connection object
     */
    function __construct($aPath, $aValues, $properties, $bShortcut = false, $oConnection = false) {
        parent::__construct($aPath, $aValues, $properties, $bShortcut, $oConnection);
        $this->aSelectedFields = Array('gtf_engine_id', 'name', 'period', 'enabled', 'server_id', 'fme_engine_id', 'server_name', 'fme_name', 'tags');
    }

    /**
     * @SWG\Get(path="/gtfengines/{gtf_engine_id}", 
     *   tags={"GtfEngines"},
     *   summary="Get GtfEngine",
     *   description="Request to get GtfEngine by id",
     *   operationId="GET",
     *   produces={"application/xml", "application/json"},
     *   @SWG\Parameter(
     *     name="token",
     *     in="query",
     *     description="user token",
     *     required=true,
     *     type="string"
     *   ),
     * @SWG\Parameter(
     *     name="gtf_engine_id",
     *     in="path",
     *     description="user id",
     *     required=true,
     *     type="integer",
     *   format="int32"
     *   ),
     * @SWG\Parameter(
     *     name="attributs",
     *     in="query",
     *     description="list of attributs",
     *     required=false,
     *     type="string"
     *   ),
     *   @SWG\Response(
     *         response=200,
     *         description="Poprerties Response",
     *         @SWG\Schema(ref="#/definitions/gtfengines")
     *     )
     *  )
     */

    /**
     * get informations about mode
     */
    function GET() {
        require $this->sRessourcesFile;
        $this->aFields = $this->getFields($this->aProperties['schema_gtf'], "v_gtf_engine", "gtf_engine_id");
    }

    /**
     * delete an user
     */
    function DELETE() {
        $this->oConnection->oBd->delete($this->aProperties['schema_gtf'], 'v_gtf_engine', 'gtf_engine_id', $this->aValues["my_vitis_id"], 'integer');
        if ($this->oConnection->oBd->enErreur()) {
            $this->oError = new VitisError(1, $this->oConnection->oBd->getBDMessage());
        } else {
            $this->aFields['gtf_engine_id'] = $this->aValues["my_vitis_id"];
        }
    }

}

?>